FileContents : The document data and checksum.
Fields
contents: StringData for printing labels, in the form of a Base64-encoded, GZip-compressed string.
file_type: FileTypechecksum: StringAn MD5 hash to validate the PDF document data, in the form of a Base64-encoded string.
Implementations
sourceimpl FileContents
impl FileContents